## $Id: utils.py 17952 2024-11-05 11:51:11Z henrik $
##
## Copyright (C) 2012 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""Customize general helper utilities for Kofa.
"""
from copy import deepcopy
from kofacustom.nigeria.utils.utils import NigeriaKofaUtils

class CustomKofaUtils(NigeriaKofaUtils):
    """A collection of methods subject to customization.
    """

    PAYMENT_CATEGORIES = {
        'schoolfee': 'School Fee',
        'clearance': 'Acceptance Fee',
        'bed_allocation': 'Bed Reservation',
        'hostel_maintenance': 'Hostel Fee',
        #'transfer': 'Transfer Fee',
        #'gown': 'Gown Hire Fee',
        'application': 'Application Fee',
        #'app_balance': 'Application Fee Balance',
        'transcript': 'Transcript Fee',
        'transcript_student': 'Transcript Fee Students Copy',
        'transcript_local': 'Transcript Fee Local Copy',
        'transcript_inter': 'Transcript Fee International Copy',
        #'late_registration': 'Late Course Registration Fee',
        #'combi': 'Combi Payment',
        'med_reg':'Medical Registration Fee',
        'teaching_practice':'Teaching Practice Fee',
        'ijmb_exam':'IJMB Examination Fees',
        'union': 'Student Union Due',
        }

    SELECTABLE_PAYMENT_CATEGORIES = {
        'schoolfee': 'School Fee',
        'clearance': 'Acceptance Fee',
        #'bed_allocation': 'Bed Reservation (free of charge)',
        'hostel_maintenance': 'Hostel Fee',
        'med_reg':'Medical Registration Fee',
        'teaching_practice':'Teaching Practice Fee',
        'ijmb_exam':'IJMB Examination Fees',
        #'transcript': 'Transcript Fee',
        'transcript_student': 'Transcript Fee Students Copy',
        'transcript_local': 'Transcript Fee Local Copy',
        'transcript_inter': 'Transcript Fee International Copy',
        #'union': 'Student Union Due',
        }

    def selectable_payment_categories(self, student):
        return self.SELECTABLE_PAYMENT_CATEGORIES

    PREVIOUS_PAYMENT_CATEGORIES = deepcopy(SELECTABLE_PAYMENT_CATEGORIES)

    DISABLE_PAYMENT_GROUP_DICT = {
        'sf_all':    'School Fee - All',
        'sf_ugft':   'School Fee - Undergraduate Full-Time',
        }

    COURSE_CATEGORY_DICT = {
        'C':'Core Course (C)',
        'R':'Required Courses (R)',
        'E':'Elective Courses (E)',
        }
        
    STUDY_MODES_DICT = {
        'ug_ft': 'Undergraduate Full-Time',
        'ug_pt': 'Undergraduate Part-Time',
        'found': 'Foundation',
        'dp_ft': 'Full-Time Diploma Programmes',
        'dp_pt': 'Part-Time Diploma Programmes',
        'de_ft': 'Direct Entry Full-Time Programmes',
        'nce_ft': 'NCE Full-Time',
        'nce_pt': 'NCE Part-Time',
        'pde': 'Professional Diploma in Education Programmes',
        'trc': 'TRCN Programmes',
        }

    APP_CATS_DICT = {
        'basic': 'UAS, PUTME, PCE, PRENCE',
        'basic_de': 'UAS, PUTME, PUDE, PCE, PRENCE',
        'no': 'No Application',
        'pre': 'Pre-Degree Programmes',
        'jupeb': 'JUPEB Pre-Degree (Foundation) Programmes',
        'ijmb': 'IJMB Foundation School Programmes',
        'dp_ft': 'Full-Time Diploma Programmes',
        'dp_pt': 'Part-Time Diploma Programmes',
        'ug_pt': 'Undergraduate Part-Time Programmes',
        'df': 'Digital Forensic for Professionals and Academia',
        'law': 'Certificate in Law Programme',
        'pde': 'Professional Diploma in Education Programmes',
        'trcdeg': 'TRCN Degree Programmes',
        'trcnce': 'TRCN NCE Programmes',
        }

    SPECIAL_HANDLING_DICT = {
        'regular': 'Regular Hostel',
        'blocked': 'Blocked Hostel',
        'oyibu': 'Owa-Oyibu Campus Hostel',
        'alero': 'Owa-Alero Campus Hostel',
        }
